==> gravitee-alert-api-1.3.0-sources.jar: io/gravitee/alert/api/event/Event.java <==
/**
 * Copyright (C) 2015 The Gravitee team (http://gravitee.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.gravitee.alert.api.event;

import java.util.Map;

/**
 * @author David BRASSELY (david.brassely at graviteesource.com)
 * @author GraviteeSource Team
 */
public interface Event extends Comparable<Event> {

    /**
     * Event identifier.
     *
     * @return Event identifier.
     */
    String id();

    /**
     * Event timestamp.
     *
     * @return Event timestamp.
     */
    long timestamp();

    /**
     * Type of event: healtcheck, request, node_monitor, ...
     * @return
     */
    String type();

    Map<String, String> context();

    Map<String, Object> properties();

    static DefaultEvent.Builder at(long timestamp) {
        return new DefaultEvent.Builder(timestamp);
    }

    static DefaultEvent.Builder now() {
        return at(System.currentTimeMillis());
    }

    @Override
    default int compareTo(Event o) {
        int c = this.id().compareTo(o.id());
        if (0 != c)
            return c;

        return Long.compare(this.timestamp(), o.timestamp());
    }
}

==> gravitee-alert-api-1.9.1-sources.jar: io/gravitee/alert/api/event/Event.java <==
/**
 * Copyright (C) 2015 The Gravitee team (http://gravitee.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.gravitee.alert.api.event;

import java.util.Map;

/**
 * @author David BRASSELY (david.brassely at graviteesource.com)
 * @author GraviteeSource Team
 */
public interface Event extends Comparable<Event> {
    String PROPERTY_INSTALLATION = "installation";
    String PROPERTY_ORGANIZATION = "organization";
    String PROPERTY_ENVIRONMENT = "environment";

    /**
     * Event identifier.
     *
     * @return Event identifier.
     */
    String id();

    /**
     * Event timestamp.
     *
     * @return Event timestamp.
     */
    long timestamp();

    /**
     * Type of event: healtcheck, request, node_monitor, ...
     * @return
     */
    String type();

    Map<String, String> context();

    Map<String, Object> properties();

    static DefaultEvent.Builder at(long timestamp) {
        return new DefaultEvent.Builder(timestamp);
    }

    static DefaultEvent.Builder now() {
        return at(System.currentTimeMillis());
    }

    @Override
    default int compareTo(Event o) {
        int c = this.id().compareTo(o.id());
        if (0 != c) return c;

        return Long.compare(this.timestamp(), o.timestamp());
    }
}
